@@ -4,8 +4,10 @@ __license__ = "MPL 2.0"
 
 
 from shpc.logger import logger
-import shpc.utils
-from .base import ContainerTechnology, ContainerName
+import shpc.utils as utils
+import shpc.main.wrappers
+import shpc.main.container.update as update
+from .base import ContainerTechnology
 
 from datetime import datetime
 from glob import glob
@@ -72,50 +74,94 @@ class SingularityContainer(ContainerTechnology):
             logger.exit("Found more than one sif in module folder.")
         return sif[0]
 
-    def add(self, sif, module_name, modulefile, template, **kwargs):
+    def add(self, module_name, image, config, container_yaml, **kwargs):
         """
-        Manually add a registry container.
+        Manually add a registry container, e.g., generating a container.yaml
+        for an existing container file. container_yaml is the destination file.
+        If it's already exisitng, it's loaded into config. Otherwise we are
+        using a template config.
         """
-        module_dir = os.path.dirname(modulefile)
+        if ":" not in module_name:
+            tag = "latest"
+        else:
+            module_name, tag = module_name.split(":", 1)
 
-        # Ensure the container exists
-        sif = os.path.abspath(sif)
-        if not os.path.exists(sif):
-            logger.exit("%s does not exist." % sif)
+        # Cut out early if the tag isn't latest, and we already have it
+        # DO NOT call config.tags here, it will add an empty latest
+        if tag != "latest" and tag in config._config["tags"]:
+            if not utils.confirm_action(
+                "Tag %s already is defined, are you sure you want to overwrite it? "
+                % tag
+            ):
+                return
 
-        # First ensure that we aren't using a known namespace
-        for registry_dir, _ in self.iter_registry():
-            for subfolder in module_name.split("/"):
-                registry_dir = os.path.join(registry_dir, subfolder)
-                if os.path.exists(registry_dir):
-                    logger.exit(
-                        "%s is a known registry namespace, choose another for a custom addition."
-                        % subfolder
-                    )
+        # Destination for container in registry
+        dest_dir = os.path.dirname(container_yaml)
+        utils.mkdir_p(dest_dir)
 
-        # The user can have a different container directory defined
-        container_dir = self.container_dir(module_name)
-        shpc.utils.mkdirp([container_dir, module_dir])
+        # Add a docker (or local image) and return the config
+        if image.startswith("docker://"):
+            config = self._add_docker_image(
+                module_name, tag, image, config, container_yaml, **kwargs
+            )
+        else:
+            config = self._add_local_image(
+                module_name, tag, image, config, container_yaml, **kwargs
+            )
 
-        # Name the container appropriately
-        name = module_name.replace("/", "-")
-        digest = shpc.utils.get_file_hash(sif)
-        dest = os.path.join(container_dir, "%s-sha256:%s.sif" % (name, digest))
-        shutil.copyfile(sif, dest)
-
-        # Parse the module name for the user
-        parsed_name = ContainerName(module_name)
-
-        self.install(
-            modulefile,
-            dest,
-            module_name,
-            template,
-            parsed_name=parsed_name,
-            features=kwargs.get("features"),
+        # Final save of config, and tell the user we're done!
+        config.save(container_yaml)
+        logger.info(
+            "Registry entry %s was added! Before shpc install, edit:" % module_name
         )
-        self.add_environment(module_dir, {}, self.settings.environment_file)
-        logger.info("Module %s was created." % (module_name))
+        print(container_yaml)
+
+    def _add_local_image(self, name, tag, image, config, container_yaml, **kwargs):
+        """
+        A subtype of "add" that adds a local image, e.g.,:
+
+        shpc add <container.sif> <uri>
+        """
+        if not os.path.exists(image):
+            logger.exit(f"{image} does not exist.")
+
+        digest = utils.get_file_hash(image)
+
+        # Destination for container in registry
+        dest_dir = os.path.dirname(container_yaml)
+
+        # The destination container in the registry folder
+        container_digest = "sha256:%s" % digest
+        container_name = "%s.sif" % container_digest
+        dest_container = os.path.join(dest_dir, container_name)
+
+        # Update the config path and latest
+        config.set("path", container_name)
+        config.set("latest", {tag: container_digest})
+        config.add_tag(tag, container_digest)
+
+        # Only copy if it's not there yet (enforces naming by hash)
+        if not os.path.exists(dest_container):
+            shutil.copyfile(image, dest_container)
+        return config
+
+    def _add_docker_image(self, name, tag, image, config, container_yaml, **kwargs):
+        """
+        A subtype of "add" that adds a docker URI, e.g.,:
+
+        shpc add docker://vanessa/salad
+        shpc add docker://vanessa/salad dinosaur/salad
+        TODO need to test if different URI will work
+        """
+        # Container name should not have tag
+        container_name = image.replace("docker://", "").split(":", 1)[0]
+        tags = update.get_container_tag(container_name, tag)
+
+        # Update the config path and latest
+        config.set("docker", container_name)
+        config.set("latest", tags)
+        config.add_tag(tag, tags[tag])
+        return config
 
     def install(
         self,
@@ -199,7 +245,7 @@ class SingularityContainer(ContainerTechnology):
             parsed_name=parsed_name,
             wrapper_scripts=wrapper_scripts,
         )
-        shpc.utils.write_file(module_path, out)
+        utils.write_file(module_path, out)
 
     def registry_pull(self, module_dir, container_dir, config, tag):
         """
@@ -357,7 +403,7 @@ class SingularityContainer(ContainerTechnology):
         Given a test file, run it and respond accordingly.
         """
         command = [self.command, "exec", image, "/bin/bash", test_script]
-        result = shpc.utils.run_command(command)
+        result = utils.run_command(command)
 
         # We can't run on incompatible hosts
         if (
