@@ -42,6 +42,8 @@ if { ![info exists ::env(PODMAN_COMMAND_OPTS)] } {
     setenv PODMAN_COMMAND_OPTS ""
 } 
 
+{% include "includes/load_view.tcl" %}
+
 # Variables
 
 set name        "{{ name }}"
@@ -55,8 +57,8 @@ set helpcommand "This module is a {{ docker }} container wrapper for {{ name }}
 {% if labels %}{% for key, value in labels.items() %}set {{ key }} "{{ value }}"
 {% endfor %}{% endif %}
 
-# directory containing this modulefile (dynamically defined)
-set moduleDir   "[file dirname ${ModulesCurrentModulefile}]"
+# directory containing this modulefile, once symlinks resolved (dynamically defined)
+set moduleDir   [file dirname [expr { [string equal [file type ${ModulesCurrentModulefile}] "link"] ? [file readlink ${ModulesCurrentModulefile}] : ${ModulesCurrentModulefile} }]]
 
 # conflict with modules with the same alias name
 conflict {{ parsed_name.tool }}
