@@ -52,6 +52,8 @@ aliases_list = {
             "command": {"type": "string"},
             "singularity_options": {"type": "string"},
             "docker_options": {"type": "string"},
+            "singularity_script": {"type": "string"},
+            "docker_script": {"type": "string"},
         },
     },
 }
@@ -139,6 +141,8 @@ settingsProperties = {
         ]
     },
     "enable_tty": {"type": "boolean"},
+    "views_base": {"type": ["string", "null"]},
+    "default_view": {"type": ["string", "null"]},
     "wrapper_scripts": wrapper_scripts,
     "container_tech": {"type": "string", "enum": ["singularity", "podman", "docker"]},
     "singularity_shell": {"type": "string", "enum": shells},
@@ -168,3 +172,29 @@ settings = {
     "properties": settingsProperties,
     "additionalProperties": False,
 }
+
+# Views
+
+viewProperties = {
+    "system_modules": {"type": "array", "items": {"type": "string"}},
+    "modules": {"type": "array", "items": {"type": "string"}},
+    "name": {"type": "string"},
+}
+
+
+views = {
+    "$schema": schema_url,
+    "title": "Views Schema",
+    "type": "object",
+    "required": [
+        "view",
+    ],
+    "properties": {
+        "view": {
+            "type": "object",
+            "properties": viewProperties,
+            "additionalProperties": False,
+        }
+    },
+    "additionalProperties": False,
+}
